@@ -3,7 +3,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 148 2012-01-11 22:56:09Z saturn $
+# $Id: smsconEditorMain.py 250 2012-08-12 14:08:00Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.10.6-1'
+Version = '0.10.9-4'
 
 import os
 import sys
@@ -332,12 +332,6 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
-       ##Connect the GUI Buttons with actions
-       QtCore.QObject.connect(self.ui.btnStart,    QtCore.SIGNAL('clicked()'), self.doStart)
-       QtCore.QObject.connect(self.ui.btnStop,     QtCore.SIGNAL('clicked()'), self.doStop)
-       QtCore.QObject.connect(self.ui.btnBoot,     QtCore.SIGNAL('clicked()'), self.doBoot)
-       QtCore.QObject.connect(self.ui.btnUnBoot,   QtCore.SIGNAL('clicked()'), self.doUnBoot)
-        
        ##Connect the GUI Buttons with windows
        QtCore.QObject.connect(self.ui.pushButtonGeneral,  QtCore.SIGNAL('clicked()'), self.doGeneral)
        QtCore.QObject.connect(self.ui.pushButtonCommands, QtCore.SIGNAL('clicked()'), self.doCommands)
@@ -349,72 +343,6 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        QtCore.QObject.connect(self.ui.pushButtonLog,      QtCore.SIGNAL('clicked()'), self.doReadLog)
        QtCore.QObject.connect(self.ui.pushButtonAbout,    QtCore.SIGNAL('clicked()'), self.doAbout)
        QtCore.QObject.connect(self.ui.pushButtonNewPass,  QtCore.SIGNAL('clicked()'), self.doUpdatePassword)
-        
-
-       ##Set values in the GUI.
-       self.SetSystemValues()
-
-    ##Not needed to restart since SMSCON 0.9.10. 
-    ##Code is left here for future use: delete logs when closing the editor?        
-    # def closeEvent(self, event): 
-       # """Cleanup on close."""
-
-       # event.accept()
-
-    def SetSystemValues(self):
-       '''Set GUI values from the current operation'''
-       
-       DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
-       BOOTSTATE = IsFileReadable(os.path.join(smscon.BootPath, smscon.BootFile))
-       
-       if DAEMONSTATE.endswith('running'):
-          self.ui.btnStop.setEnabled(True)
-          self.ui.btnStop.setChecked(True)
-          self.ui.btnStart.setEnabled(False)
-       else:
-          self.ui.btnStart.setEnabled(True)
-          self.ui.btnStart.setChecked(True)
-          self.ui.btnStop.setEnabled(False)
-          
-       if BOOTSTATE:
-          self.ui.btnUnBoot.setEnabled(True)
-          self.ui.btnUnBoot.setChecked(True)
-          self.ui.btnBoot.setEnabled(False)
-       else:
-          self.ui.btnBoot.setEnabled(True)
-          self.ui.btnBoot.setChecked(True)
-          self.ui.btnUnBoot.setEnabled(False)
-          
-    def doStart(self):
-       if self.isSmsconTestActive: # -start would not stop a running daemon and would left it at test mode.
-          message = os.popen('sudo smscon -restart 2>&1').read()
-       else:
-          message = os.popen('sudo smscon -start 2>&1').read()
-       self.isSmsconTestActive = False
-       showMessage(message)
-       self.SetSystemValues()
-
-    def doRestart(self):
-       message = os.popen('sudo smscon -restart 2>&1').read()
-       self.isSmsconTestActive = False
-       showMessage(message)
-       self.SetSystemValues()
-
-    def doStop(self):
-       message = os.popen('sudo smscon -stop 2>&1').read()
-       self.isSmsconTestActive = False
-       showMessage(message)
-       self.SetSystemValues()
-
-    def doBoot(self):
-       message = os.popen('sudo smscon -boot 2>&1').read()
-       showMessage(message)
-       self.SetSystemValues()
-
-    def doUnBoot(self):
-       message = os.popen('sudo smscon -unboot 2>&1').read()
-       showMessage(message)
-       self.SetSystemValues()
 
     ##Open new Windows:    
     def doAbout(self):
@@ -462,22 +390,109 @@ class smsconEditorInit(QtGui.QMainWindow):     ## Initialise SMSCON
        self.show()       
 
        ##Connect the GUI Buttons with actions
+       QtCore.QObject.connect(self.ui.btnStart,    QtCore.SIGNAL('clicked()'), self.doStart)
+       QtCore.QObject.connect(self.ui.btnStop,     QtCore.SIGNAL('clicked()'), self.doStop)
+       QtCore.QObject.connect(self.ui.btnBoot,     QtCore.SIGNAL('clicked()'), self.doBoot)
+       QtCore.QObject.connect(self.ui.btnUnBoot,   QtCore.SIGNAL('clicked()'), self.doUnBoot)
+        
           ##Create Settings
-       QtCore.QObject.connect(self.ui.btnInit,     QtCore.SIGNAL('clicked()'), self.doInit)
-       QtCore.QObject.connect(self.ui.btnReset,    QtCore.SIGNAL('clicked()'), self.doReset)
-       QtCore.QObject.connect(self.ui.btnDelIMSI,  QtCore.SIGNAL('clicked()'), self.doDelIMSI)
-       QtCore.QObject.connect(self.ui.btnAddIMSI,  QtCore.SIGNAL('clicked()'), self.doAddIMSI)
+       QtCore.QObject.connect(self.ui.btnInit,        QtCore.SIGNAL('clicked()'), self.doInit)
+       QtCore.QObject.connect(self.ui.btnReset,       QtCore.SIGNAL('clicked()'), self.doReset)
+       QtCore.QObject.connect(self.ui.btnIMSIremove,  QtCore.SIGNAL('clicked()'), self.doIMSIremove)
+       QtCore.QObject.connect(self.ui.btnIMSIdelete,  QtCore.SIGNAL('clicked()'), self.doIMSIdelete)
+       QtCore.QObject.connect(self.ui.btnIMSIadd,     QtCore.SIGNAL('clicked()'), self.doAddIMSI)
 
+       ##Set values in the GUI.
+       self.SetSystemValues()
+
+    def SetSystemValues(self):
+       '''Set GUI values from the current operation'''
+       
+       DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
+       BOOTSTATE = IsFileReadable(os.path.join(smscon.BootPath, smscon.BootFile))
+       
+       if DAEMONSTATE.endswith('running'):
+          self.ui.btnStop.setEnabled(True)
+          self.ui.btnStop.setChecked(True)
+          self.ui.btnStart.setEnabled(False)
+       else:
+          self.ui.btnStart.setEnabled(True)
+          self.ui.btnStart.setChecked(True)
+          self.ui.btnStop.setEnabled(False)
+          
+       if BOOTSTATE:
+          self.ui.btnUnBoot.setEnabled(True)
+          self.ui.btnUnBoot.setChecked(True)
+          self.ui.btnBoot.setEnabled(False)
+       else:
+          self.ui.btnBoot.setEnabled(True)
+          self.ui.btnBoot.setChecked(True)
+          self.ui.btnUnBoot.setEnabled(False)
+          
+    def doStart(self):
+       if self.isSmsconTestActive: # -start would not stop a running daemon and would left it at test mode.
+          message = os.popen('sudo smscon -restart 2>&1').read()
+       else:
+          message = os.popen('sudo smscon -start 2>&1').read()
+       self.isSmsconTestActive = False
+       showMessage(message)
+       self.SetSystemValues()
+
+    def doRestart(self):
+       message = os.popen('sudo smscon -restart 2>&1').read()
+       self.isSmsconTestActive = False
+       showMessage(message)
+       self.SetSystemValues()
+
+    def doStop(self):
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential functionality", "This will stop the operation of SMSCON.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
+          
+       message = os.popen('sudo smscon -stop 2>&1').read()
+       self.isSmsconTestActive = False
+       showMessage(message)
+       self.SetSystemValues()
+
+    def doBoot(self):
+       message = os.popen('sudo smscon -boot 2>&1').read()
+       showMessage(message)
+       self.SetSystemValues()
+
+    def doUnBoot(self):
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential functionality", "This will remove the application from the boot sequence and SMSCON will not be able to start in the next reboot.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
+
+       message = os.popen('sudo smscon -unboot 2>&1').read()
+       showMessage(message)
+       self.SetSystemValues()
+       
     def doInit(self):
-        os.system('sudo smscon -init!')
-        message =   'SMSCON has been initialised to the default configuration.\n' \
-                    'This editor will now quit...\n\n' \
-                    'You will need to open it again and edit your new configuration.'
-        showMessage(message)
-        self.close()
-        sys.exit(0)
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential information", "This action will replace all your custom settings with default values.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
+    
+       os.system('sudo smscon -init!')
+       message =   'SMSCON has been initialised to the default configuration.\n' \
+                   'This editor will now quit...\n\n' \
+                   'You will need to open it again and edit your new configuration.'
+       showMessage(message)
+       self.close()
+       sys.exit(0)
         
     def doReset(self):
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential functionality", "This will stop and remove SMSCON from the boot sequence as well as remove all your settings.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
 
        # Note: DO NOT sys.exit() here! If we would do so, the recent editor copy of
        # active configuration would be (re-)established on next start of editor.
@@ -495,7 +510,23 @@ class smsconEditorInit(QtGui.QMainWindow):     ## Initialise SMSCON
                    '\n3. Start SMSCON operation and 4. Enable SMSCON on device boot.'
        showMessage(message)
 
-    def doDelIMSI(self):
+    def doIMSIremove(self):
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential functionality", "This will revoke the authorisation of your currently inserted SIM.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
+          
+       message = os.popen('sudo smscon -remove imsi 2>&1').read()
+       showMessage(message)
+
+    def doIMSIdelete(self):
+       questionMessage = QtGui.QMessageBox.question(self, "Warning: removing essential functionality", "This will revoke the authorisation of all SIMs on this device.\n\nProceed?",
+                                                QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,
+                                                QtGui.QMessageBox.No)
+       if questionMessage != QtGui.QMessageBox.Yes:
+          return
+          
        message = os.popen('sudo smscon -del imsi 2>&1').read()
        showMessage(message)
 
@@ -538,7 +569,10 @@ class smsconEditorGeneral(QtGui.QMainWindow):  ## General Settings
        self.ui.checkBoxLowBattery    .setChecked(configTrue(editConf['AUTOBATREPORT']))
        self.ui.checkBoxKeyboardDetect.setChecked(configTrue(editConf['KEYBOARDDETECT']))
        self.ui.checkBoxDeviceLock    .setChecked(configTrue(editConf['AUTODEVICELOCK']))
-       self.ui.checkBoxNewSIMUnlock  .setChecked(configTrue(editConf['SIMUNLOCK']))
+       #self.ui.checkBoxNewSIMUnlock  .setChecked(configTrue(editConf['SIMUNLOCK']))
+       self.ui.comboBoxSIMOk         .setCurrentIndex(['keep', 'lockifnopin', 'lockalways'].index(editConf['LOCKMODE_OKSIM'])) 
+       self.ui.comboBoxSIMBad        .setCurrentIndex(['keep', 'unlock', 'lock'].index(editConf['LOCKMODE_BADSIM'])) 
+       self.ui.comboBoxSIMNew        .setCurrentIndex(['keep', 'unlock', 'lock'].index(editConf['LOCKMODE_NEWSIM'])) 
        self.ui.checkBoxSilence       .setChecked(configTrue(editConf['SILENCEDEVICE']))
            
        self.ui.checkBoxEnableRetry   .setChecked(configTrue(editConf['ENABLERESEND']))
@@ -571,7 +605,10 @@ class smsconEditorGeneral(QtGui.QMainWindow):  ## General Settings
        newConf["COMMANDREPLY"]   = configYesNo(self.ui.checkBoxCommandReply.isChecked())
        newConf["AUTODEVICELOCK"] = configYesNo(self.ui.checkBoxDeviceLock.isChecked())
        newConf["AUTOBATREPORT"]  = configYesNo(self.ui.checkBoxLowBattery.isChecked())
-       newConf["SIMUNLOCK"]      = configYesNo(self.ui.checkBoxNewSIMUnlock.isChecked())
+       #newConf["SIMUNLOCK"]      = configYesNo(self.ui.checkBoxNewSIMUnlock.isChecked())
+       newConf["LOCKMODE_OKSIM"] = self.ui.comboBoxSIMOk.currentText()
+       newConf["LOCKMODE_BADSIM"]= self.ui.comboBoxSIMBad.currentText()
+       newConf["LOCKMODE_NEWSIM"] = self.ui.comboBoxSIMNew.currentText()
        newConf["SILENCEDEVICE"]  = configYesNo(self.ui.checkBoxSilence.isChecked())
        newConf["KEYBOARDDETECT"] = configYesNo(self.ui.checkBoxKeyboardDetect.isChecked())
 
